==> v2.0.4.tar.gz: zyos_go_order_relate_rule/db/model/block_star_chain.go <==
package model

import (
	"time"
)

type BlockStarChain struct {
	Id                             int       `json:"id" xorm:"not null pk autoincr comment('主键id') INT(11)"`
	IsUse                          int       `json:"is_use" xorm:"not null default 0 comment('是否开启（否：0；是：1）') TINYINT(1)"`
	Coin1                          int       `json:"coin_1" xorm:"not null default 0 comment('coinId_1(类似于区块币)') INT(11)"`
	Coin2                          int       `json:"coin_2" xorm:"not null default 0 comment('coinId_2(类似于静态贡献值)') INT(11)"`
	Coin3                          int       `json:"coin_3" xorm:"not null default 0 comment('coinId_3(类似于动态贡献值)') INT(11)"`
	InitialEverydayPublishCoin     string    `json:"initial_everyday_publish_coin" xorm:"not null default 0.0000000000 comment('初始每日区块币发行数量') DECIMAL(28,10)"`
	NowEverydayPublishCoin         string    `json:"now_everyday_publish_coin" xorm:"not null default 0.0000000000 comment('当前每日区块币发行数量') DECIMAL(28,10)"`
	TodayPublishCoin               string    `json:"today_publish_coin" xorm:"not null default 0.0000000000 comment('今日区块币发行数量(若为0,则按当前每日区块币发行数量)') DECIMAL(28,10)"`
	EveryThirtyDaysReduceRate      string    `json:"every_thirty_days_reduce_rate" xorm:"not null default 5.00 comment('每三十日递减发行百分比') DECIMAL(5,2)"`
	TotalNowCoin                   string    `json:"total_now_coin" xorm:"not null default 0.0000000000 comment('当前区块币总量') DECIMAL(28,10)"`
	TotalPublishCoin               string    `json:"total_publish_coin" xorm:"not null default 0.0000000000 comment('累计区块币发行总量') DECIMAL(28,10)"`
	TotalDestroyCoin               string    `json:"total_destroy_coin" xorm:"not null default 0.0000000000 comment('累计区块币销毁总量') DECIMAL(28,10)"`
	TotalRemainderCoin             string    `json:"total_remainder_coin" xorm:"not null default 0.0000000000 comment('累计区块币剩余总量') DECIMAL(28,10)"`
	InitialCoinTotal               string    `json:"initial_coin_total" xorm:"not null default 0.0000000000 comment('初始区块币总量') DECIMAL(28,10)"`
	PlatformGuidePriceForCoin      string    `json:"platform_guide_price_for_coin" xorm:"not null default 0.0000000000 comment('平台区块币指导价') DECIMAL(22,10)"`
	StartAt                        string    `json:"start_at" xorm:"not null default '0000-00' comment('起始时间(0000-00)') CHAR(50)"`
	PlatformBusinessDiscountRate   string    `json:"platform_business_discount_rate" xorm:"not null default 0.00 comment('平台商家让利百分比') DECIMAL(5,2)"`
	ConsumeReturnContributionRate  string    `json:"consume_return_contribution_rate" xorm:"not null default 100.00 comment('消费返贡献值比例') DECIMAL(5,2)"`
	PublishCoinDynamicRate         string    `json:"publish_coin_dynamic_rate" xorm:"not null default 45.00 comment('区块币发行动态占比') DECIMAL(5,2)"`
	PublishCoinStaticRate          string    `json:"publish_coin_static_rate" xorm:"not null default 45.00 comment('区块币发行静态占比') DECIMAL(5,2)"`
	PublishCoinOperationCenterRate string    `json:"publish_coin_operation_center_rate" xorm:"not null default 3.00 comment('区块币发行运营中心占比') DECIMAL(5,2)"`
	OperationCenterForUserLevel    int       `json:"operation_center_for_user_level" xorm:"not null default 0 comment('运营中心分红对应会员等级') INT(11)"`
	PublishCoinOtherRate           string    `json:"publish_coin_other_rate" xorm:"not null default 7.00 comment('区块币发行其他占比') DECIMAL(5,2)"`
	OtherForUserLevel              string    `json:"other_for_user_level" xorm:"comment('其他分红对应会员等级') TEXT"`
	RewardDestroyCoinRate          string    `json:"reward_destroy_coin_rate" xorm:"not null default 70.00 comment('商家打赏销毁区块币比例') DECIMAL(5,2)"`
	RewardSettings                 string    `json:"reward_settings" xorm:"comment('奖励设置') TEXT"`
	CreateAt                       time.Time `json:"create_at" xorm:"not null default 'CURRENT_TIMESTAMP' comment('创建时间') TIMESTAMP"`
	UpdateAt                       time.Time `json:"update_at" xorm:"default 'CURRENT_TIMESTAMP' comment('更新时间') TIMESTAMP"`
	SellLimit                      string    `json:"sell_limit" xorm:"comment('挂卖条件') TEXT"`
}

==> v2.1.2.tar.gz: zyos_go_order_relate_rule/db/model/block_star_chain.go <==
package model

import (
	"time"
)

type BlockStarChain struct {
	Id                             int       `json:"id" xorm:"not null pk autoincr comment('主键id') INT(11)"`
	IsUse                          int       `json:"is_use" xorm:"not null default 0 comment('是否开启（否：0；是：1）') TINYINT(1)"`
	Coin1                          int       `json:"coin_1" xorm:"coin_1 not null default 0 comment('coinId_1(类似于区块币)') INT(11)"`
	Coin2                          int       `json:"coin_2" xorm:"coin_2 not null default 0 comment('coinId_2(类似于静态贡献值)') INT(11)"`
	Coin3                          int       `json:"coin_3" xorm:"coin_3 not null default 0 comment('coinId_3(类似于动态贡献值)') INT(11)"`
	InitialEverydayPublishCoin     string    `json:"initial_everyday_publish_coin" xorm:"not null default 0.0000000000 comment('初始每日区块币发行数量') DECIMAL(28,10)"`
	NowEverydayPublishCoin         string    `json:"now_everyday_publish_coin" xorm:"not null default 0.0000000000 comment('当前每日区块币发行数量') DECIMAL(28,10)"`
	TodayPublishCoin               string    `json:"today_publish_coin" xorm:"not null default 0.0000000000 comment('今日区块币发行数量(若为0,则按当前每日区块币发行数量)') DECIMAL(28,10)"`
	EveryThirtyDaysReduceRate      string    `json:"every_thirty_days_reduce_rate" xorm:"not null default 5.00 comment('每三十日递减发行百分比') DECIMAL(5,2)"`
	TotalNowCoin                   string    `json:"total_now_coin" xorm:"not null default 0.0000000000 comment('当前区块币总量') DECIMAL(28,10)"`
	TotalPublishCoin               string    `json:"total_publish_coin" xorm:"not null default 0.0000000000 comment('累计区块币发行总量') DECIMAL(28,10)"`
	TotalDestroyCoin               string    `json:"total_destroy_coin" xorm:"not null default 0.0000000000 comment('累计区块币销毁总量') DECIMAL(28,10)"`
	TotalRemainderCoin             string    `json:"total_remainder_coin" xorm:"not null default 0.0000000000 comment('累计区块币剩余总量') DECIMAL(28,10)"`
	InitialCoinTotal               string    `json:"initial_coin_total" xorm:"not null default 0.0000000000 comment('初始区块币总量') DECIMAL(28,10)"`
	PlatformGuidePriceForCoin      string    `json:"platform_guide_price_for_coin" xorm:"not null default 0.0000000000 comment('平台区块币指导价') DECIMAL(22,10)"`
	StartAt                        string    `json:"start_at" xorm:"not null default '0000-00' comment('起始时间(0000-00)') CHAR(50)"`
	PlatformBusinessDiscountRate   string    `json:"platform_business_discount_rate" xorm:"not null default 0.00 comment('平台商家让利百分比') DECIMAL(5,2)"`
	ConsumeReturnContributionRate  string    `json:"consume_return_contribution_rate" xorm:"not null default 100.00 comment('消费返贡献值比例') DECIMAL(5,2)"`
	PublishCoinDynamicRate         string    `json:"publish_coin_dynamic_rate" xorm:"not null default 45.00 comment('区块币发行动态占比') DECIMAL(5,2)"`
	PublishCoinStaticRate          string    `json:"publish_coin_static_rate" xorm:"not null default 45.00 comment('区块币发行静态占比') DECIMAL(5,2)"`
	PublishCoinOperationCenterRate string    `json:"publish_coin_operation_center_rate" xorm:"not null default 3.00 comment('区块币发行运营中心占比') DECIMAL(5,2)"`
	OperationCenterForUserLevel    int       `json:"operation_center_for_user_level" xorm:"not null default 0 comment('运营中心分红对应会员等级') INT(11)"`
	PublishCoinOtherRate           string    `json:"publish_coin_other_rate" xorm:"not null default 7.00 comment('区块币发行其他占比') DECIMAL(5,2)"`
	OtherForUserLevel              string    `json:"other_for_user_level" xorm:"comment('其他分红对应会员等级') TEXT"`
	RewardDestroyCoinRate          string    `json:"reward_destroy_coin_rate" xorm:"not null default 70.00 comment('商家打赏销毁区块币比例') DECIMAL(5,2)"`
	RewardSettings                 string    `json:"reward_settings" xorm:"comment('奖励设置') TEXT"`
	CreateAt                       time.Time `json:"create_at" xorm:"not null default 'CURRENT_TIMESTAMP' comment('创建时间') TIMESTAMP"`
	UpdateAt                       time.Time `json:"update_at" xorm:"default 'CURRENT_TIMESTAMP' comment('更新时间') TIMESTAMP"`
	SellLimit                      string    `json:"sell_limit" xorm:"comment('挂卖条件') TEXT"`
}
